@@ -37,6 +37,12 @@ class ReleaseClusterHostGroupRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
+	def get_EnableGracefulDecommission(self):
+		return self.get_query_params().get('EnableGracefulDecommission')
+
+	def set_EnableGracefulDecommission(self,EnableGracefulDecommission):
+		self.add_query_param('EnableGracefulDecommission',EnableGracefulDecommission)
+
 	def get_ClusterId(self):
 		return self.get_query_params().get('ClusterId')
 
@@ -53,4 +59,16 @@ class ReleaseClusterHostGroupRequest(RpcRequest):
 		return self.get_query_params().get('InstanceIdList')
 
 	def set_InstanceIdList(self,InstanceIdList):
-		self.add_query_param('InstanceIdList',InstanceIdList)
\ No newline at end of file
+		self.add_query_param('InstanceIdList',InstanceIdList)
+
+	def get_ReleaseNumber(self):
+		return self.get_query_params().get('ReleaseNumber')
+
+	def set_ReleaseNumber(self,ReleaseNumber):
+		self.add_query_param('ReleaseNumber',ReleaseNumber)
+
+	def get_DecommissionTimeout(self):
+		return self.get_query_params().get('DecommissionTimeout')
+
+	def set_DecommissionTimeout(self,DecommissionTimeout):
+		self.add_query_param('DecommissionTimeout',DecommissionTimeout)
\ No newline at end of file
